@@ -776,8 +776,7 @@ void AudioFile::open(const char *name, Mode m, timeout_t framing)
 		info.format = riff;
 	}
 
-	if(!strncmp((char *)filehdr + 8, "WAVE", 4) &&
-	   info.format == riff)
+	if(!strncmp((char *)filehdr + 8, "WAVE", 4) && info.format == riff)
 	{
 		header = 12;
 		for(;;)
@@ -871,13 +870,18 @@ void AudioFile::open(const char *name, Mode m, timeout_t framing)
 		goto done;
 	}
 
-	if(!strnicmp((char *)filehdr, "ID3\003", 4))
+	if(!strnicmp((char *)filehdr, "ID3", 3))
 	{
 		afSeek(10);
 		info.order = __BIG_ENDIAN;
-		header = getLong(filehdr + 6) + 10;
-		if(filehdr[5])
-			header += getLong(filehdr + 10);
+		header = 10;
+		if(filehdr[5] & 0x10)
+			header += 10;	// footer
+
+		header += (filehdr[9] & 0x7f);
+		header += (filehdr[8] & 0x7f) * 128;
+		header += (filehdr[7] & 0x7f) * 128 * 128;
+		header += (filehdr[6] & 0x7f) * 128 * 128 * 128;
 		afSeek(header);
 		afRead(filehdr, 4);
 		goto mp3;
@@ -917,10 +921,16 @@ done:
 void AudioFile::mp3info(mpeg_audio *mp3)
 {
 	info.headersize = 4;
+	info.padding = 0;
+
+	if(mp3->mp_pad)
+		info.padding = 1;
 
 	switch(mp3->mp_layer)
 	{
 	case 0x03:
+		if(mp3->mp_pad)
+			info.padding = 4;
 		info.encoding = mp1Audio;
 		break;
 	case 0x02:
@@ -1109,12 +1119,12 @@ void Audio::Info::set(void)
 	{
 	case mp1Audio:
 		framecount = 384;
-		framesize = (12 * bitrate / rate) * 4 + headersize;
+		framesize = (12 * bitrate / rate) * 4 + headersize + padding;
 		return;
 	case mp2Audio:
 	case mp3Audio:
 		framecount = 1152;
-		framesize = (144 * bitrate / rate) + headersize;
+		framesize = (144 * bitrate / rate) + headersize + padding;
 		return;
 	}
 	if(!framesize)
@@ -1333,7 +1343,7 @@ rescan:
 			afSeek(getAbsolutePosition() - 3);
 			goto rescan;
 		}	
-		mp3info(mp3);	
+		mp3info(mp3);
 		count = afRead(addr + 4, info.framesize - 4);
 		if(count > 0)
 			count += 4;
