@@ -984,6 +984,19 @@ size_t Audio::toBytes(Encoding encoding, unsigned long samples)
 	return frames * getFrame(encoding);
 }
 
+size_t Audio::maxFramesize(Info &info)
+{
+	switch(info.encoding)
+	{
+	case mp1Audio:
+		return 682;
+	case mp2Audio:
+	case mp3Audio:
+		return 1735;
+	}
+	return info.framesize;
+}
+
 size_t Audio::toBytes(Info &info, unsigned long samples)
 {
 	if(!samples)
